@@ -1,4 +1,5 @@
 context('mst.R')
+
 test_that('MST edges calculated correctly', {
   set.seed(0)
   points <- matrix(c(0.1, 0, 1.9, 2, 1.1, 1,
@@ -16,5 +17,10 @@ test_that('MST edges calculated correctly', {
     expect_equal(MSTEdges(distances, FALSE),
                  MSTEdges(distances, TRUE, points[, 1], points[, 2]))
   }
+  skip_if_not_installed('vdiffr')
   vdiffr::expect_doppelganger('MST plotting', MSTPlot)
 })
+test_that("MST handles large distance matrices", {
+  x <- dist(0:300)
+  expect_equal(c(300, 2), dim(MSTEdges(x)))
+})
